==> csbase-common-2.0.1-sources.jar: csbase/logic/algorithms/parsers/HiddenParameterParser.java <==
package csbase.logic.algorithms.parsers;

import csbase.exception.ParseException;
import csbase.logic.algorithms.parameters.HiddenParameter;
import csbase.logic.algorithms.parameters.ParameterGroup;

/**
 * <p>
 * Analisador de {@link HiddenParameter}.
 * </p>
 * 
 * <p>
 * Este parser l os atributos de parmetros do tipo oculto. O elemento corrente
 * do {@link XmlParser analisador de XML} precisa ser um elemento
 * {@link HiddenParameter}.
 * </p>
 * 
 */
public class HiddenParameterParser extends ParameterParser implements
  ParameterFactory {

  /**
   * <p>
   * O elemento {@value #HIDDEN_PARAMETER_ELEMENT}: descreve as propriedades de
   * um {@link HiddenParameter parmetro do tipo oculto}.
   * </p>
   * <p>
   *  filho do elemento {@link ParameterGroup}.
   * </p>
   */
  static final String HIDDEN_PARAMETER_ELEMENT = "oculto";

  /**
   * <p>
   * O atributo {@value #HIDDEN_PARAMETER_ELEMENT_VALUE_ATTRIBUTE} do elemento
   * {@link #HIDDEN_PARAMETER_ELEMENT}. Indica o valor do parmetro. 
   * obrigatrio e tipo  string.
   * </p>
   */
  private static final String HIDDEN_PARAMETER_ELEMENT_VALUE_ATTRIBUTE =
    "valor";

  /**
   * {@inheritDoc}
   */
  @Override
  public HiddenParameter createParameter(XmlParser parser,
    String defaultCommandLinePattern, ParameterGroup group)
    throws ParseException {
    String name =
      parser
        .extractAttributeValue(SimpleParameterParser.PARAMETER_ELEMENT_NAME_ATTRIBUTE);
    String value =
      parser.extractAttributeValue(HIDDEN_PARAMETER_ELEMENT_VALUE_ATTRIBUTE);
    parser.checkAttributes();
    String commandLinePattern =
      loadCommandLinePattern(parser, defaultCommandLinePattern);
    if (commandLinePattern == null) {
      throw new ParseException(
        "No  possvel criar um parmetro oculto com formato no comando vazio.\n"
          + "Parmetro: {0}\nValor: {1}.", name, value);
    }
    return new HiddenParameter(name, value, commandLinePattern);
  }

}

==> csbase-common-2.2.0-sources.jar: csbase/logic/algorithms/parsers/HiddenParameterParser.java <==
package csbase.logic.algorithms.parsers;

import csbase.exception.ParseException;
import csbase.logic.algorithms.parameters.HiddenParameter;
import csbase.logic.algorithms.parameters.ParameterGroup;
import csbase.logic.algorithms.parameters.SimpleAlgorithmConfigurator;

/**
 * <p>
 * Analisador de {@link HiddenParameter}.
 * </p>
 * 
 * <p>
 * Este parser l os atributos de parmetros do tipo oculto. O elemento corrente
 * do {@link XmlParser analisador de XML} precisa ser um elemento
 * {@link HiddenParameter}.
 * </p>
 * 
 */
public class HiddenParameterParser extends ParameterParser implements
  ParameterFactory {

  /**
   * <p>
   * O elemento {@value #HIDDEN_PARAMETER_ELEMENT}: descreve as propriedades de
   * um {@link HiddenParameter parmetro do tipo oculto}.
   * </p>
   * <p>
   *  filho do elemento {@link ParameterGroup}.
   * </p>
   */
  static final String HIDDEN_PARAMETER_ELEMENT = "oculto";

  /**
   * <p>
   * O atributo {@value #HIDDEN_PARAMETER_ELEMENT_VALUE_ATTRIBUTE} do elemento
   * {@link #HIDDEN_PARAMETER_ELEMENT}. Indica o valor do parmetro. 
   * obrigatrio e tipo  string.
   * </p>
   */
  private static final String HIDDEN_PARAMETER_ELEMENT_VALUE_ATTRIBUTE =
    "valor";

  /**
   * {@inheritDoc}
   */
  @Override
  public HiddenParameter createParameter(XmlParser parser,
    String defaultCommandLinePattern, ParameterGroup group,
    SimpleAlgorithmConfigurator configurator) throws ParseException {
    String name = parser.extractAttributeValue(
      SimpleParameterParser.PARAMETER_ELEMENT_NAME_ATTRIBUTE);
    String value = parser.extractAttributeValue(
      HIDDEN_PARAMETER_ELEMENT_VALUE_ATTRIBUTE);
    parser.checkAttributes();
    String commandLinePattern = loadCommandLinePattern(parser,
      defaultCommandLinePattern);
    if (commandLinePattern == null) {
      throw new ParseException(
        "No  possvel criar um parmetro oculto com formato no comando vazio.\n"
          + "Parmetro: {0}\nValor: {1}.", name, value);
    }
    return new HiddenParameter(name, value, commandLinePattern);
  }

}
